@@ -58,8 +58,8 @@ public:
 	SpeexCommon(Encoding enc, const char *name);
 	~SpeexCommon();
 
-	unsigned encode(Linear buffer, void *dest, unsigned lsamples, bool buffered);
-	unsigned decode(Linear buffer, void *source, unsigned lsamples, bool buffered);
+	unsigned encode(Linear buffer, void *dest, unsigned lsamples);
+	unsigned decode(Linear buffer, void *source, unsigned lsamples);
 
         AudioCodec *getByInfo(Info &info);
         AudioCodec *getByFormat(const char *format);
@@ -151,7 +151,7 @@ AudioCodec *SpeexCommon::getByInfo(Info &info)
 	}
 }
 
-unsigned SpeexCommon::decode(Linear buffer, void *src, unsigned lsamples, bool buffered)
+unsigned SpeexCommon::decode(Linear buffer, void *src, unsigned lsamples)
 {
 	unsigned count = lsamples / info.framecount;
 	unsigned result = 0;
@@ -170,7 +170,7 @@ unsigned SpeexCommon::decode(Linear buffer, void *src, unsigned lsamples, bool b
 	return result;
 }
 
-unsigned SpeexCommon::encode(Linear buffer, void *dest, unsigned lsamples, bool buffered)
+unsigned SpeexCommon::encode(Linear buffer, void *dest, unsigned lsamples)
 {
 	unsigned count = lsamples / info.framecount;
 	unsigned result = 0;
