@@ -122,6 +122,8 @@ public:
 	typedef	unsigned long	timeout_t;
 #endif
 
+	static const unsigned ndata;
+
 	typedef struct
 	{
 	float v2;
@@ -956,6 +958,15 @@ public:
          */
 	virtual ssize_t getBuffer(Encoded data, size_t size) = 0;
 
+	/**
+	 * Get's a packet of audio data.
+	 *
+	 * @return count of data received.
+	 * @param data to get.
+	 */
+	inline ssize_t getPacket(Encoded data)
+		{return getBuffer(data, 0);};
+
 	/**
 	 * Get raw data and assure is in native machine endian.
 	 *
@@ -1523,6 +1534,15 @@ public:
 
 	virtual ~AudioStream();
 
+	/**
+	 * Virtual for packet i/o intercept.
+	 *
+	 * @return bytes read.
+	 * @param data encoding buffer.
+	 * @param count requested.
+	 */
+	ssize_t getBuffer(Encoded data, size_t count);
+
 	/**
 	 * Open existing audio file for streaming.
 	 *
@@ -1605,6 +1625,15 @@ public:
 	 */
 	unsigned putEncoded(Encoded address, unsigned frames = 1);
 
+	/**
+	 * Get a packet of data from the file.  This uses the codec
+	 * to determine what a true packet boundry is.
+	 *
+	 * @param buffer to save encoded data.
+	 * @return number of bytes read as packet.
+	 */
+	ssize_t getPacket(Encoded data);
+
 	/**
 	 * Get and automatically convert audio file data into
 	 * mono linear audio samples.
@@ -1809,13 +1838,22 @@ public:
 	/**
 	 * Encode a linear sample frame into the codec sample buffer.
 	 *
-	 * @param number of bytes written.
+	 * @return number of bytes written.
 	 * @param buffer linear sample buffer to use.
 	 * @param dest buffer to store encoded results.
-	 * @param number of samples or buffered bytes.
-	 * @param true if buffered mode.
+	 * @param number of samples.
 	 */
-	virtual unsigned encode(Linear buffer, void *dest, unsigned number = 0, bool buffered = false) = 0;
+	virtual unsigned encode(Linear buffer, void *dest, unsigned number = 0) = 0;
+
+	/**
+	 * Encode linear samples buffered into the coded.
+	 *
+	 * @return number of bytes written or 0 if incomplete.
+	 * @param buffer linear samples to post.
+	 * @param destination of encoded audio.
+	 * @param number of samples being buffered.
+	 */
+	virtual unsigned encodeBuffered(Linear Buffer, Encoded dest, unsigned number);
 
 	/**
 	 * Decode the sample frame into linear samples.
@@ -1823,10 +1861,45 @@ public:
 	 * @return number of bytes scanned or returned
 	 * @param buffer sample buffer to save linear samples into.
 	 * @param source for encoded data.
-	 * @param number of samples to extract or bytes to buffer.
-	 * @patam true if buffered mode.
+	 * @param number of samples to extract.
 	 */
-	virtual unsigned decode(Linear buffer, void *source, unsigned number = 0, bool buffered = false) = 0;
+	virtual unsigned decode(Linear buffer, void *source, unsigned number = 0) = 0;
+
+	/**
+	 * Buffer and decode data into linear samples.  This is needed
+	 * for audio formats that have irregular packet sizes.
+	 *
+	 * @return number of samples actually decoded.
+	 * @param destination for decoded data.
+	 * @param source for encoded data.
+	 * @param number of bytes being sent.
+	 */
+	virtual unsigned decodeBuffered(Linear buffer, Encoded source, unsigned len);
+
+	/**
+	 * Get estimated data required for buffered operations.
+	 *
+	 * @return estimated number of bytes required for decode.
+	 */
+	virtual unsigned getEstimated(void);
+
+	/**
+	 * get required samples for encoding.
+	 *
+	 * @return required number of samples for encoder buffer.
+	 */
+	virtual unsigned getRequired(void);
+
+	/**
+	 * Get a packet of data rather than decode.  This is tied with
+	 * getEstimated.
+	 *
+	 * @return size of data packet or 0 if not complete.
+	 * @param destination to save.
+	 * @param data to push into buffer.
+	 * @param number of bytes to push.
+	 */
+	virtual unsigned getPacket(Encoded destination, Encoded data, unsigned size);
 
 	/**
 	 * Get an info description for this codec.
