@@ -39,6 +39,10 @@
 #include "audio2.h"
 #include <cstdio>
 
+#ifndef	WIN32
+#include <sys/stat.h>
+#endif
+
 using namespace ost;
 
 static const char * const ErrorStrs[] = {
@@ -554,6 +558,9 @@ void AudioFile::create(const char *name, Info *myinfo, bool exclusive, timeout_t
 		case g723_5bit:
 			setLong(aufile + 12, 26);
 			break;
+		case gsmVoice:
+			setLong(aufile + 12, 28);
+			break;
 		case alawAudio:
 			setLong(aufile + 12, 27);
 			break;
@@ -707,54 +714,17 @@ void AudioFile::open(const char *name, Mode m, timeout_t framing)
 	if(!ext)
 		goto done;
 
-	if(!stricmp(ext, ".ul") || !stricmp(ext, ".ulaw") || !stricmp(ext, ".mulaw"))
-	{
-		info.encoding = mulawAudio;
-		goto done;
-	}
-
-	if(!stricmp(ext, ".al") || !stricmp(ext, ".alaw"))
-	{
-		info.encoding = alawAudio;
-		goto done;
-	}
-
-	if(!stricmp(ext, ".sw") || !stricmp(ext, ".raw") || !stricmp(ext, ".pcm"))
-	{
-		info.encoding = pcm16Mono;
-		goto done;
-	}
-
-	if(!stricmp(ext, ".vox"))
-	{
-		info.encoding = voxADPCM;
-		goto done;
-	}
-
-	if(!stricmp(ext, ".adpcm"))
-	{
-		info.encoding = g721ADPCM;
-		goto done;
-	}
-
-	if(!stricmp(ext, ".a24"))
-	{
-		info.encoding = g723_3bit;
-		goto done;
-	}
-
-	if(!stricmp(ext, ".a40"))
-	{
-		info.encoding = g723_5bit;
-		goto done;
-	}
-
-	if(!stricmp(ext, ".cda"))
+	info.encoding = Audio::getEncoding(ext);
+	switch(info.encoding)
 	{
+	case cdaStereo:
 		info.order = __LITTLE_ENDIAN;
-		info.encoding = cdaStereo;
-		goto done;
-	}
+		break;
+	case unknownEncoding:
+		info.encoding = mulawAudio;
+	default:
+		break;
+	}		
 
 	strcpy((char *)filehdr, ".xxx");
 
@@ -855,6 +825,9 @@ void AudioFile::open(const char *name, Mode m, timeout_t framing)
 		case 27:
 			info.encoding = alawAudio;
 			break;
+		case 28:
+			info.encoding = gsmVoice;
+			break;
 		case 1:
 			info.encoding = mulawAudio;
 			break;
@@ -1145,6 +1118,10 @@ void Audio::Info::set(void)
 
 void AudioFile::close(void)
 {
+#ifndef	WIN32
+	struct stat ino;
+#endif
+
 	unsigned char buf[58];
 	if(! isOpen())
 		return;
@@ -1152,6 +1129,7 @@ void AudioFile::close(void)
 	if(mode != modeWrite)
 	{
 		afClose();
+		clear();
 		return;
 	}
 
@@ -1172,6 +1150,10 @@ void AudioFile::close(void)
 	switch(info.format) {
 	case riff:
 	case wave:
+#ifndef	WIN32
+		fstat(file.fd, &ino);
+		length = ino.st_size;		
+#endif
 		// RIFF header
 		setLong(buf + 4, length - 8);
 
@@ -1185,6 +1167,10 @@ void AudioFile::close(void)
 		afWrite(buf, 58);
 		break;
 	case snd:
+#ifndef	WIN32
+		fstat(file.fd, &ino);
+		length = ino.st_size;
+#endif
 		setLong(buf + 8, length - header);
 		afWrite(buf, 12);
 		break;
