@@ -157,6 +157,8 @@ bool AudioCodec::load(Encoding e)
 	case mulawAudio:
 	case alawAudio:
 		return load("g.711");
+	case g721ADPCM:
+		return load("g.721");
 	case g723_2bit:
 	case g723_3bit:
 	case g723_5bit:
@@ -285,6 +287,7 @@ Audio::Level AudioCodec::getImpulse(void *data, unsigned samples)
 {
 	unsigned long sum = 0;
 	Linear ldata = new Sample[samples];
+	Linear lptr = ldata;
 	long count = decode(ldata, data, samples);
 
 	samples = count;
@@ -296,7 +299,7 @@ Audio::Level AudioCodec::getImpulse(void *data, unsigned samples)
 			sum += *(ldata++);
 	}
 
-	delete[] ldata;
+	delete[] lptr;
 	return (Level)(sum / count);
 }
 
@@ -304,6 +307,7 @@ Audio::Level AudioCodec::getPeak(void *data, unsigned samples)
 {
 	Level max = 0, value;
 	Linear ldata = new Sample[samples];
+	Linear lptr = ldata;
 	long count = decode(ldata, data, samples);
 
 	samples = count;
@@ -316,7 +320,36 @@ Audio::Level AudioCodec::getPeak(void *data, unsigned samples)
 			max = value;
 	}
 
-	delete[] ldata;
+	delete[] lptr;
 	return max;
 }
 
+unsigned AudioCodec::getEstimated(void)
+{
+	return info.framesize;
+}
+
+unsigned AudioCodec::getRequired(void)
+{
+	return info.framecount;
+}
+
+unsigned AudioCodec::encodeBuffered(Linear buffer, Encoded source, unsigned samples)
+{
+	return encode(buffer, source, samples);
+}
+
+unsigned AudioCodec::decodeBuffered(Linear buffer, Encoded source, unsigned bytes)
+{
+	return decode(buffer, source, toSamples(info, bytes));
+}
+
+unsigned AudioCodec::getPacket(Encoded packet, Encoded data, unsigned bytes)
+{
+	if(bytes != info.framesize)
+		return 0;
+
+	memcpy(packet, data, bytes);
+	return bytes;
+}
+
